#[unsafe(no_mangle)]pub extern "C" fn crashlog_deinit(ctx: *mut CrashLogContext)Expand description
Releases the memory allocated for the Crash Log global context.
#[unsafe(no_mangle)]pub extern "C" fn crashlog_deinit(ctx: *mut CrashLogContext)Releases the memory allocated for the Crash Log global context.