crashlog_export_to_cper

Function crashlog_export_to_cper 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn crashlog_export_to_cper( context: *mut CrashLogContext, crashlog: *const CrashLog, ) -> *mut CrashLogExport
Available on crate feature ffi only.
Exports the Crash Log as a CPER record.

The memory allocated by this function can be freed using the crashlog_release_export function.

Safety

This must be called with a pointer to a CrashLogContext that was earlier obtained by calling the crashlog_init function.

The crashlog pointer must be valid and obtained using one of the crashlog_read_*() functions.