crashlog_get_next_node_child

Function crashlog_get_next_node_child 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn crashlog_get_next_node_child( context: *mut CrashLogContext, children: *mut CrashLogNodeChildren<'_>, ) -> *const Node
Available on crate feature ffi only.
Returns the next child of a Crash Log register tree node.

The memory allocated for the iterator will be automatically freed by this function once all the children have been returned.

Safety

This must be called with a pointer to a CrashLogContext that was earlier obtained by calling the crashlog_init function.

The children pointer must be obtained using the crashlog_get_node_children function. If the previous call to this function returns a NULL pointer, the iterator must not be used again as it is freed automatically by this function.

Errors

Returns a NULL pointer if one of the arguments is NULL or if no more node is available in the iterator.