crashlog_get_node_by_path

Function crashlog_get_node_by_path 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn crashlog_get_node_by_path( context: *mut CrashLogContext, node: *const Node, path: *const c_char, ) -> *const Node
Available on crate feature ffi only.
Returns the Crash Log register tree node located at the provided path.

Safety

This must be called with a pointer to a CrashLogContext that was earlier obtained by calling the crashlog_init function.

The node pointer must be obtained using the crashlog_decode, crashlog_get_next_node_child, or the crashlog_get_node_by_path functions.

The path must be a valid nul-terminated string.

Errors

Returns a NULL pointer if one of the arguments is NULL or if the node does not exist.