crashlog_get_node_children

Function crashlog_get_node_children 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn crashlog_get_node_children<'a>( context: *mut CrashLogContext, node: *const Node, ) -> *mut CrashLogNodeChildren<'a>
Available on crate feature ffi only.
Returns a iterator over the children of a Crash Log register tree node.

The actual children can be obtained from the iterator using the crashlog_get_next_node_child function.

Safety

This must be called with a pointer to a CrashLogContext that was earlier obtained by calling the crashlog_init function.

The node pointer must be obtained using the crashlog_decode, crashlog_get_next_node_child, or the crashlog_get_node_by_path functions.

Errors

Returns a NULL pointer if one of the arguments is NULL.