crashlog_get_node_value

Function crashlog_get_node_value 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn crashlog_get_node_value( context: *mut CrashLogContext, node: *const Node, value: *mut u64, ) -> bool
Available on crate feature ffi only.
Copies the value stored in the Crash Log register tree node into the qword pointed by the value argument.

Returns true if the value has been written. If an error happens or if the node does not store any value, false is returned.

Safety

This must be called with a pointer to a CrashLogContext that was earlier obtained by calling the crashlog_init function.

The node pointer must be obtained using the crashlog_decode, crashlog_get_next_node_child, or the crashlog_get_node_by_path functions.

The value pointer must point to a writable memory region of 8 bytes.