crashlog_next

Function crashlog_next 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn crashlog_next( context: *mut CrashLogContext, crashlogs: *mut CrashLogs, ) -> *mut CrashLog
Available on crate feature ffi only.
Returns the next Crash Log in the iterator.

The memory allocated for the iterator will be automatically freed by this function once all the children have been returned.

Safety

This must be called with a pointer to a CrashLogContext that was earlier obtained by calling the crashlog_init function.

If the previous call to this function returns a NULL pointer, the iterator must not be used again as it is freed automatically by this function.

Errors

Returns a NULL pointer if one of the arguments is NULL or if no more Crash Logs is available in the iterator.