#[unsafe(no_mangle)]pub extern "C" fn crashlog_release_export(node: *mut CrashLogExport)Expand description
Releases the memory allocated for the Crash Log export.
#[unsafe(no_mangle)]pub extern "C" fn crashlog_release_export(node: *mut CrashLogExport)Releases the memory allocated for the Crash Log export.