pub struct CrashLogExport { /* private fields */ }Available on crate feature
ffi only.Expand description
Opaque type that stores a representation of a Crash Log.
This structure is created by the crashlog_export_to_json and crashlog_export_to_cper
functions and must be released using the crashlog_release_export function.
The actual content of the structure can be accessed from this structure using the
crashlog_read_export function.