pub struct CrashLogNodeChildren<'a> { /* private fields */ }Available on crate feature
ffi only.Expand description
Opaque type that represents an iterator over the children of a Crash Log register tree node.
This structure is created by the crashlog_get_node_children function.
The actual nodes can be accessed from this structure using the crashlog_get_next_node_child
function.