#[unsafe(no_mangle)]pub unsafe extern "C" fn crashlog_decode(
context: *mut CrashLogContext,
crashlog: *const CrashLog,
) -> *mut NodeAvailable on crate feature
ffi only.Expand description
Decodes a CrashLog into a register tree.
Returns a Node object that represents the root node of the register tree.
The memory allocated by this function can be released using the crashlog_release_nodes
function.
Safety
This must be called with a pointer to a CrashLogContext that was earlier obtained by
calling the crashlog_init function.
The crashlog pointer must be obtained using one of the crashlog_read_from_* functions.
Errors
Returns a NULL pointer if one of the arguments is NULL.