#[unsafe(no_mangle)]pub extern "C" fn crashlog_deinit(ctx: *mut CrashLogContext)Available on crate feature
ffi only.Expand description
Releases the memory allocated for the Crash Log global context.
#[unsafe(no_mangle)]pub extern "C" fn crashlog_deinit(ctx: *mut CrashLogContext)ffi only.Releases the memory allocated for the Crash Log global context.