#[unsafe(no_mangle)]pub unsafe extern "C" fn crashlog_export_to_json(
context: *mut CrashLogContext,
node: *const Node,
) -> *mut CrashLogExportAvailable on crate features
ffi and serialize only.Expand description
Exports the Crash Log register tree (Node) as JSON file.
The memory allocated by this function can be freed using the crashlog_release_export
function.
Safety
This must be called with a pointer to a CrashLogContext that was earlier obtained by
calling the crashlog_init function.
The node pointer must be obtained using the crashlog_decode function.
Errors
Returns a NULL pointer if one of the arguments is NULL or if an error happens during the
generation of the JSON.