#[unsafe(no_mangle)]pub extern "C" fn crashlog_init() -> *mut CrashLogContextAvailable on crate feature
ffi only.Expand description
Initializes the Crash Log Decoder Context
This function allocates the memory needed to store the CrashLogContext,
initializes it, and returns a pointer to it.
The value returned by this function must be passed to any subsequent calls made to the other functions exposed by this library.
The memory allocated by this function can be released using the crashlog_deinit function.
Errors
Returns a NULL pointer if the context cannot be initialized.