crashlog_read_from_windows_event_logs

Function crashlog_read_from_windows_event_logs 

#[unsafe(no_mangle)]
pub extern "C" fn crashlog_read_from_windows_event_logs( context: *mut CrashLogContext, ) -> *mut CrashLogs
Available on crate feature ffi and (Windows and crate feature extraction) only.
Reads the Crash Log records from the Windows Event Logs.

Errors

Returns a NULL pointer if the Crash Log records cannot be found.