#[unsafe(no_mangle)]pub extern "C" fn crashlog_release_export(node: *mut CrashLogExport)Available on crate feature
ffi only.Expand description
Releases the memory allocated for the Crash Log export.
#[unsafe(no_mangle)]pub extern "C" fn crashlog_release_export(node: *mut CrashLogExport)ffi only.Releases the memory allocated for the Crash Log export.