#[unsafe(no_mangle)]pub extern "C" fn crashlog_release_nodes(node: *mut Node)
Releases the memory allocated for the Crash Log register tree.
The root node of the tree is expected to be passed to this function.