pub struct CrashLogs { /* private fields */ }Available on crate feature
ffi only.Expand description
Opaque type that represents an iterator over Crash Logs.
The actual content of the structure can be accessed from this structure using the
crashlog_next function.